@@ -64,14 +64,15 @@ def test_gitlab_code_climate_reporter():
     reporter.display_messages(None)
 
     expected_result = [{
-        "description": "Line too long (1/2)",
+        "description": "C0301: Line too long (1/2)",
+        "severity": "minor",
         "location": {
             "path": "0123",
             "lines": {
                 "begin": 1,
             }
         },
-        "fingerprint": "dd37ec22b50cc049ca355d0f59efc88e"
+        "fingerprint": "21e7b7887a841a99f73b9cf1771bf387"
     }]
     report_result = json.loads(output.getvalue())
     assert report_result == expected_result
